@@ -108,6 +108,7 @@
    #:standard-slot-definition
    #:standard-writer-method
 
+   #:ensure-finalized
    #:ensure-method
    #:fix-slot-initargs
    #:required-args
@@ -151,7 +152,6 @@
    #:generic-function-methods
    #:generic-function-name
    #:intern-eql-specializer
-   #:intern-eql-specializer*
    #-clisp #:make-method-lambda
    #:map-dependents
    #:method-function
